@@ -381,12 +381,13 @@ def uninstall_host(host, *, connection=None):
 @auto_connect
 def deploy_masterfiles(host, tarball, *, connection=None):
     data = get_info(host, connection=connection)
+    print("\nDeploying to:")
     print_info(data)
     if not data["agent_version"]:
         log.error(f"Cannot deploy masterfiles on {host} - CFEngine not installed")
         return 1
     
-    scp(tarball, host, connection=connection)
+    scp(tarball, host, connection=connection, rename="masterfiles.tgz")
     ssh_cmd(connection, f"tar -xzf masterfiles.tgz")
     commands = [
         "systemctl stop cfengine3",
